Class: Recls::Entry

Inherits:
Object
  • Object
show all
Defined in:
lib/recls/entry.rb,
lib/recls/obsolete.rb

Overview

:nodoc:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(path, file_stat, search_dir, flags) ⇒ Entry

initialises an entry instance from the given path, file_stat, and search_dir



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/recls/entry.rb', line 64

def initialize(path, file_stat, search_dir, flags)

  @file_stat    = file_stat
  @flags        = flags

  @path         = Recls::Ximpl.absolute_path path
  @short_path   = nil
  @compare_path = Entry.get_compare_path_ @path
  @hash         = @compare_path.hash

  windows_drive, directory, basename, file_name, file_ext = Recls::Ximpl::Util.split_path @path

  @drive = windows_drive
  @directory_path = "#{windows_drive}#{directory}"
  @directory = directory ? directory : ''
  @directory_parts = Recls::Ximpl.directory_parts_from_directory directory
  @file_full_name = basename ? basename : ''
  @file_short_name = nil
  @file_name_only = file_name ? file_name : ''
  @file_extension = file_ext ? file_ext : ''

  @search_directory = search_dir
  @search_relative_path = Recls::Ximpl.derive_relative_path search_dir, @path
  @search_relative_directory_path = Recls::Ximpl.derive_relative_path search_dir, @directory_path
  @search_relative_directory = @search_relative_directory_path
  @search_relative_directory_parts = Recls::Ximpl.directory_parts_from_directory @search_relative_directory

  if 0 != (Recls::MARK_DIRECTORIES & flags) && directory?
    @path                 = Recls::Ximpl::Util.append_trailing_slash @path
    @search_relative_path = Recls::Ximpl::Util.append_trailing_slash @search_relative_path
  end

  @dev    = @file_stat.dev if @file_stat
  @ino    = @file_stat.ino if @file_stat
  @nlink  = @file_stat.nlink if @file_stat

  if Recls::Ximpl::OS::OS_IS_WINDOWS && @file_stat

    @dev              = @file_stat.by_handle_information.volume_id
    @ino              = @file_stat.by_handle_information.file_index
    @nlink            = @file_stat.by_handle_information.num_links
    @short_path       = @file_stat.short_path
    @file_short_name  = Recls::Ximpl::Util.split_path(@short_path)[2]
  else

    ;
  end
end

Instance Attribute Details

#compare_pathObject (readonly)

(String) A normalised form of #path that can be used in comparisons



117
118
119
# File 'lib/recls/entry.rb', line 117

def compare_path
  @compare_path
end

#directoryObject (readonly)

(String) The entry’s directory (excluding the #drive if on Windows)



128
129
130
# File 'lib/recls/entry.rb', line 128

def directory
  @directory
end

#directory_partsObject (readonly) Also known as: directoryParts

( [ String ] ) An array of directory parts, where each part ends in PATH_NAME_SEPARATOR



130
131
132
# File 'lib/recls/entry.rb', line 130

def directory_parts
  @directory_parts
end

#directory_pathObject (readonly) Also known as: dirname, directoryPath

(String) The full path of the entry’s directory (taking into account the #drive if on Windows)



125
126
127
# File 'lib/recls/entry.rb', line 125

def directory_path
  @directory_path
end

#driveObject (readonly) Also known as: uncDrive

(String) The (Windows) drive. nil if does not exist



123
124
125
# File 'lib/recls/entry.rb', line 123

def drive
  @drive
end

#file_extensionObject (readonly) Also known as: extension, fileExt

(String) The entry’s file extension



140
141
142
# File 'lib/recls/entry.rb', line 140

def file_extension
  @file_extension
end

#file_full_nameObject (readonly) Also known as: basename, file

(String) The entry’s file name (combination of #stem + #extension)



132
133
134
# File 'lib/recls/entry.rb', line 132

def file_full_name
  @file_full_name
end

#file_name_onlyObject (readonly) Also known as: stem, fileBaseName, fileName

(String) The entry’s file stem



137
138
139
# File 'lib/recls/entry.rb', line 137

def file_name_only
  @file_name_only
end

#file_short_nameObject (readonly) Also known as: shortFile

(String) The (Windows) short-form of #basename, or nil if not on Windows



134
135
136
# File 'lib/recls/entry.rb', line 134

def file_short_name
  @file_short_name
end

#pathObject (readonly)

(String) The full-path of the instance



119
120
121
# File 'lib/recls/entry.rb', line 119

def path
  @path
end

#search_directoryObject (readonly) Also known as: searchDirectory

(String) The search directory if specified; nil otherwise



143
144
145
# File 'lib/recls/entry.rb', line 143

def search_directory
  @search_directory
end

#search_relative_directoryObject (readonly)

(String) The #directory relative to #search_directory; nil if no search directory specified



147
148
149
# File 'lib/recls/entry.rb', line 147

def search_relative_directory
  @search_relative_directory
end

#search_relative_directory_partsObject (readonly)

( [ String ] ) The #directory_parts relative to #search_directory; nil if no search directory specified



151
152
153
# File 'lib/recls/entry.rb', line 151

def search_relative_directory_parts
  @search_relative_directory_parts
end

#search_relative_directory_pathObject (readonly)

(String) The #directory_path relative to #search_directory; nil if no search directory specified



149
150
151
# File 'lib/recls/entry.rb', line 149

def search_relative_directory_path
  @search_relative_directory_path
end

#search_relative_pathObject (readonly) Also known as: searchRelativePath

(String) The #path relative to #search_directory; nil if no search directory specified



145
146
147
# File 'lib/recls/entry.rb', line 145

def search_relative_path
  @search_relative_path
end

#short_pathObject (readonly)

(String) The (Windows) short-form of #path, or nil if not on Windows



121
122
123
# File 'lib/recls/entry.rb', line 121

def short_path
  @short_path
end

Instance Method Details

#<=>(rhs) ⇒ Object

compares this instance with rhs



373
374
375
376
# File 'lib/recls/entry.rb', line 373

def <=>(rhs)

  compare_path <=> rhs.compare_path
end

#==(rhs) ⇒ Object

determines whether rhs refers to the same path



357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/recls/entry.rb', line 357

def ==(rhs)

  case rhs
  when String

    return compare_path == Entry.get_compare_path_(rhs)
  when self.class

    return compare_path == rhs.compare_path
  else

    return false
  end
end

#archive?Boolean

(WINDOWS-ONLY) Indicates whether the entry has the archive bit

Returns:

  • (Boolean)


192
193
194
195
196
197
# File 'lib/recls/entry.rb', line 192

def archive?

  return false if @file_stat.nil?

  @file_stat.archive?
end

#compressed?Boolean

(WINDOWS-ONLY) Indicates whether the entry has the compressed bit

Returns:

  • (Boolean)


224
225
226
227
228
229
# File 'lib/recls/entry.rb', line 224

def compressed?

  return false if @file_stat.nil?

  @file_stat.compressed?
end

#devObject

indicates the device of the given entry

On Windows, this will be 0 if the entry cannot be opened



299
300
301
302
# File 'lib/recls/entry.rb', line 299

def dev

  @dev
end

#device?Boolean

(WINDOWS-ONLY) Indicates whether the entry is a device

Returns:

  • (Boolean)


200
201
202
203
204
205
# File 'lib/recls/entry.rb', line 200

def device?

  return false if @file_stat.nil?

  @file_stat.device?
end

#directory?Boolean Also known as: dir?, isDirectory

indicates whether the given entry represents a directory

Returns:

  • (Boolean)


241
242
243
244
245
246
247
248
249
250
# File 'lib/recls/entry.rb', line 241

def directory?

  if @file_stat.nil?

    (Recls::DETAILS_LATER | Recls::DIRECTORIES) == ((Recls::DETAILS_LATER | Recls::DIRECTORIES) & @flags)
  else

    @file_stat.directory?
  end
end

#encrypted?Boolean

(WINDOWS-ONLY) Indicates whether the entry has the encrypted bit

Returns:

  • (Boolean)


232
233
234
235
236
237
# File 'lib/recls/entry.rb', line 232

def encrypted?

  return false if @file_stat.nil?

  @file_stat.encrypted?
end

#eql?(rhs) ⇒ Boolean

determines whether rhs is an instance of Recls::Entry and refers to the same path

Returns:

  • (Boolean)


344
345
346
347
348
349
350
351
352
353
354
# File 'lib/recls/entry.rb', line 344

def eql?(rhs)

  case rhs
  when self.class

    return compare_path == rhs.compare_path
  else

    return false
  end
end

#exist?Boolean

indicates whether the given entry existed at the time the entry instance was created

Returns:

  • (Boolean)


158
159
160
161
162
163
# File 'lib/recls/entry.rb', line 158

def exist?

  return false if @file_stat.nil?

  not @file_stat.nil?
end

#file?Boolean Also known as: isFile

indicates whether the given entry represents a file

Returns:

  • (Boolean)


255
256
257
258
259
260
261
262
263
264
# File 'lib/recls/entry.rb', line 255

def file?

  if @file_stat.nil?

    (Recls::DETAILS_LATER | Recls::FILES) == ((Recls::DETAILS_LATER | Recls::FILES) & @flags)
  else

    @file_stat.file?
  end
end

#hashObject

the hash



379
380
381
382
# File 'lib/recls/entry.rb', line 379

def hash

  @hash
end

#hidden?Boolean

indicates whether the given entry is hidden

Returns:

  • (Boolean)


166
167
168
169
170
171
# File 'lib/recls/entry.rb', line 166

def hidden?

  return false if @file_stat.nil?

  @file_stat.hidden?
end

#inoObject

indicates the ino of the given entry

On Windows, this will be 0 if the entry cannot be opened



307
308
309
310
# File 'lib/recls/entry.rb', line 307

def ino

  @ino
end

#last_access_timeObject

indicates the last access time of the entry



324
325
326
327
328
329
# File 'lib/recls/entry.rb', line 324

def last_access_time

  return nil if @file_stat.nil?

  @file_stat.atime
end

#link?Boolean

indicates whether the given entry represents a link

Returns:

  • (Boolean)


267
268
269
270
271
272
# File 'lib/recls/entry.rb', line 267

def link?

  return false if @file_stat.nil?

  @file_stat.link?
end

#modification_timeObject Also known as: creationTime

indicates the modification time of the entry



332
333
334
335
336
337
# File 'lib/recls/entry.rb', line 332

def modification_time

  return nil if @file_stat.nil?

  @file_stat.mtime
end

number of links to the given entry

On Windows, this will be 0 if the entry cannot be opened



315
316
317
318
# File 'lib/recls/entry.rb', line 315

def nlink

  @nlink
end

#normal?Boolean

(WINDOWS-ONLY) Indicates whether the entry is normal

Returns:

  • (Boolean)


208
209
210
211
212
213
# File 'lib/recls/entry.rb', line 208

def normal?

  return false if @file_stat.nil?

  @file_stat.normal?
end

#readonly?Boolean Also known as: isReadOnly

indicates whether the given entry is readonly

Returns:

  • (Boolean)


174
175
176
177
178
179
# File 'lib/recls/entry.rb', line 174

def readonly?

  return false if @file_stat.nil?

  not @file_stat.writable?
end

#sizeObject

indicates the size of the given entry



286
287
288
289
290
291
# File 'lib/recls/entry.rb', line 286

def size

  return 0 if @file_stat.nil?

  @file_stat.size
end

#socket?Boolean

indicates whether the given entry represents a socket

Returns:

  • (Boolean)


275
276
277
278
279
280
# File 'lib/recls/entry.rb', line 275

def socket?

  return false if @file_stat.nil?

  @file_stat.socket?
end

#system?Boolean

(WINDOWS-ONLY) Indicates whether the entry has the system bit

Returns:

  • (Boolean)


184
185
186
187
188
189
# File 'lib/recls/entry.rb', line 184

def system?

  return false if @file_stat.nil?

  @file_stat.system?
end

#temporary?Boolean

(WINDOWS-ONLY) Indicates whether the entry has the temporary bit

Returns:

  • (Boolean)


216
217
218
219
220
221
# File 'lib/recls/entry.rb', line 216

def temporary?

  return false if @file_stat.nil?

  @file_stat.temporary?
end

#to_sObject

represents the entry as a string (in the form of the full path)



388
389
390
391
# File 'lib/recls/entry.rb', line 388

def to_s

  path
end

#to_strObject

represents the entry as a string (in the form of the full path)



394
395
396
397
# File 'lib/recls/entry.rb', line 394

def to_str

  path
end