Class: Recls::Entry

Inherits:
Object show all
Defined in:
lib/recls/entry.rb,
lib/recls/obsolete.rb

Overview

:nodoc:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(path, file_stat, search_dir, flags) ⇒ Entry

initialises an entry instance from the given path, file_stat, and search_dir



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/recls/entry.rb', line 66

def initialize(path, file_stat, search_dir, flags)

  @file_stat    = file_stat

  @path         = Recls::Ximpl.absolute_path path
  @short_path   = nil
  @compare_path = Entry.get_compare_path_ @path
  @hash         = @compare_path.hash

  windows_drive, directory, basename, file_name, file_ext = Recls::Ximpl::Util.split_path @path

  @drive = windows_drive
  @directory_path = "#{windows_drive}#{directory}"
  @directory = directory ? directory : ''
  @directory_parts = Recls::Ximpl.directory_parts_from_directory directory
  @file_full_name = basename ? basename : ''
  @file_short_name = nil
  @file_name_only = file_name ? file_name : ''
  @file_extension = file_ext ? file_ext : ''

  @search_directory = search_dir
  @search_relative_path = Recls::Ximpl.derive_relative_path search_dir, @path
  @search_relative_directory_path = Recls::Ximpl.derive_relative_path search_dir, @directory_path
  @search_relative_directory = @search_relative_directory_path
  @search_relative_directory_parts = Recls::Ximpl.directory_parts_from_directory @search_relative_directory

  if 0 != (Recls::MARK_DIRECTORIES & flags) && directory?
    @path                 = Recls::Ximpl::Util.append_trailing_slash @path
    @search_relative_path = Recls::Ximpl::Util.append_trailing_slash @search_relative_path
  end

  @dev    = @file_stat.dev if @file_stat
  @ino    = @file_stat.ino if @file_stat
  @nlink  = @file_stat.nlink if @file_stat

  if Recls::Ximpl::OS::OS_IS_WINDOWS && @file_stat

    @dev              = @file_stat.by_handle_information.volume_id
    @ino              = @file_stat.by_handle_information.file_index
    @nlink            = @file_stat.by_handle_information.num_links
    @short_path       = @file_stat.short_path
    @file_short_name  = Recls::Ximpl::Util.split_path(@short_path)[2]
  else
  end
end

Instance Attribute Details

#compare_pathObject (readonly)

(String) A normalised form of #path that can be used in comparisons



116
117
118
# File 'lib/recls/entry.rb', line 116

def compare_path
  @compare_path
end

#directoryObject (readonly)

(String) The entry’s directory (excluding the #drive if on Windows)



129
130
131
# File 'lib/recls/entry.rb', line 129

def directory
  @directory
end

#directory_partsObject (readonly) Also known as: directoryParts

([String]) An array of directory parts, where each part ends in Recls::PATH_NAME_SEPARATOR



131
132
133
# File 'lib/recls/entry.rb', line 131

def directory_parts
  @directory_parts
end

#directory_pathObject (readonly) Also known as: dirname, directoryPath

(String) The full path of the entry’s directory (taking into account the #drive if on Windows)



126
127
128
# File 'lib/recls/entry.rb', line 126

def directory_path
  @directory_path
end

#driveObject (readonly) Also known as: uncDrive

(String) The (Windows) drive. nil if does not exist



123
124
125
# File 'lib/recls/entry.rb', line 123

def drive
  @drive
end

#file_extensionObject (readonly) Also known as: extension, fileExt

(String) The entry’s file extension



141
142
143
# File 'lib/recls/entry.rb', line 141

def file_extension
  @file_extension
end

#file_full_nameObject (readonly) Also known as: basename, file

(String) The entry’s file name (combination of #stem + #extension)



133
134
135
# File 'lib/recls/entry.rb', line 133

def file_full_name
  @file_full_name
end

#file_name_onlyObject (readonly) Also known as: stem, fileBaseName, fileName

(String) The entry’s file stem



138
139
140
# File 'lib/recls/entry.rb', line 138

def file_name_only
  @file_name_only
end

#file_short_nameObject (readonly) Also known as: shortFile

(String) The (Windows) short-form of #basename, or nil if not on Windows



135
136
137
# File 'lib/recls/entry.rb', line 135

def file_short_name
  @file_short_name
end

#pathObject (readonly)

(String) The full-path of the instance



119
120
121
# File 'lib/recls/entry.rb', line 119

def path
  @path
end

#search_directoryObject (readonly) Also known as: searchDirectory

(String) The search directory if specified; nil otherwise



144
145
146
# File 'lib/recls/entry.rb', line 144

def search_directory
  @search_directory
end

#search_relative_directoryObject (readonly)

(String) The #directory relative to #search_directory; nil if no search directory specified



148
149
150
# File 'lib/recls/entry.rb', line 148

def search_relative_directory
  @search_relative_directory
end

#search_relative_directory_partsObject (readonly)

([String]) The #directory_parts relative to #search_directory; nil if no search directory specified



152
153
154
# File 'lib/recls/entry.rb', line 152

def search_relative_directory_parts
  @search_relative_directory_parts
end

#search_relative_directory_pathObject (readonly)

(String) The #directory_path relative to #search_directory; nil if no search directory specified



150
151
152
# File 'lib/recls/entry.rb', line 150

def search_relative_directory_path
  @search_relative_directory_path
end

#search_relative_pathObject (readonly) Also known as: searchRelativePath

(String) The #path relative to #search_directory; nil if no search directory specified



146
147
148
# File 'lib/recls/entry.rb', line 146

def search_relative_path
  @search_relative_path
end

#short_pathObject (readonly)

(String) The (Windows) short-form of #path, or nil if not on Windows



121
122
123
# File 'lib/recls/entry.rb', line 121

def short_path
  @short_path
end

Instance Method Details

#<=>(rhs) ⇒ Object

compares this instance with rhs



369
370
371
372
# File 'lib/recls/entry.rb', line 369

def <=>(rhs)

  compare_path <=> rhs.compare_path
end

#==(rhs) ⇒ Object

determines whether rhs refers to the same path



353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/recls/entry.rb', line 353

def ==(rhs)

  case rhs
  when String

    return compare_path == Entry.get_compare_path_(rhs)
  when self.class

    return compare_path == rhs.compare_path
  else

    return false
  end
end

#archive?Boolean

WINDOWS-ONLY

Indicates whether the entry has the archive bit

Returns:

  • (Boolean)


193
194
195
196
197
198
# File 'lib/recls/entry.rb', line 193

def archive?

  return false if @file_stat.nil?

  @file_stat.archive?
end

#compressed?Boolean

WINDOWS-ONLY

Indicates whether the entry has the compressed bit

Returns:

  • (Boolean)


225
226
227
228
229
230
# File 'lib/recls/entry.rb', line 225

def compressed?

  return false if @file_stat.nil?

  @file_stat.compressed?
end

#devObject

indicates the device of the given entry

On Windows, this will be 0 if the entry cannot be opened



293
294
295
296
# File 'lib/recls/entry.rb', line 293

def dev

  @dev
end

#device?Boolean

WINDOWS-ONLY

Indicates whether the entry is a device

Returns:

  • (Boolean)


201
202
203
204
205
206
# File 'lib/recls/entry.rb', line 201

def device?

  return false if @file_stat.nil?

  @file_stat.device?
end

#directory?Boolean Also known as: dir?, isDirectory

indicates whether the given entry represents a directory

Returns:

  • (Boolean)


242
243
244
245
246
247
# File 'lib/recls/entry.rb', line 242

def directory?

  return false if @file_stat.nil?

  @file_stat.directory?
end

#encrypted?Boolean

WINDOWS-ONLY

Indicates whether the entry has the encrypted bit

Returns:

  • (Boolean)


233
234
235
236
237
238
# File 'lib/recls/entry.rb', line 233

def encrypted?

  return false if @file_stat.nil?

  @file_stat.encrypted?
end

#eql?(rhs) ⇒ Boolean

determines whether rhs is an instance of Entry and refers to the same path

Returns:

  • (Boolean)


340
341
342
343
344
345
346
347
348
349
350
# File 'lib/recls/entry.rb', line 340

def eql?(rhs)

  case rhs
  when self.class

    return compare_path == rhs.compare_path
  else

    return false
  end
end

#exist?Boolean

indicates whether the given entry existed at the time the entry instance was created

Returns:

  • (Boolean)


159
160
161
162
163
164
# File 'lib/recls/entry.rb', line 159

def exist?

  return false if @file_stat.nil?

  not @file_stat.nil?
end

#file?Boolean Also known as: isFile

indicates whether the given entry represents a file

Returns:

  • (Boolean)


252
253
254
255
256
257
# File 'lib/recls/entry.rb', line 252

def file?

  return false if @file_stat.nil?

  @file_stat.file?
end

#hashObject

the hash



375
376
377
378
# File 'lib/recls/entry.rb', line 375

def hash

  @hash
end

#hidden?Boolean

indicates whether the given entry is hidden

Returns:

  • (Boolean)


167
168
169
170
171
172
# File 'lib/recls/entry.rb', line 167

def hidden?

  return false if @file_stat.nil?

  @file_stat.hidden?
end

#inoObject

indicates the ino of the given entry

On Windows, this will be 0 if the entry cannot be opened



302
303
304
305
# File 'lib/recls/entry.rb', line 302

def ino

  @ino
end

#last_access_timeObject

indicates the last access time of the entry



320
321
322
323
324
325
# File 'lib/recls/entry.rb', line 320

def last_access_time

  return nil if @file_stat.nil?

  @file_stat.atime
end

#link?Boolean

indicates whether the given entry represents a link

Returns:

  • (Boolean)


260
261
262
263
264
265
# File 'lib/recls/entry.rb', line 260

def link?

  return false if @file_stat.nil?

  @file_stat.link?
end

#modification_timeObject Also known as: creationTime

indicates the modification time of the entry



328
329
330
331
332
333
# File 'lib/recls/entry.rb', line 328

def modification_time

  return nil if @file_stat.nil?

  @file_stat.mtime
end

number of links to the given entry

On Windows, this will be 0 if the entry cannot be opened



311
312
313
314
# File 'lib/recls/entry.rb', line 311

def nlink

  @nlink
end

#normal?Boolean

WINDOWS-ONLY

Indicates whether the entry is normal

Returns:

  • (Boolean)


209
210
211
212
213
214
# File 'lib/recls/entry.rb', line 209

def normal?

  return false if @file_stat.nil?

  @file_stat.normal?
end

#readonly?Boolean Also known as: isReadOnly

indicates whether the given entry is readonly

Returns:

  • (Boolean)


175
176
177
178
179
180
# File 'lib/recls/entry.rb', line 175

def readonly?

  return false if @file_stat.nil?

  not @file_stat.writable?
end

#sizeObject

indicates the size of the given entry



279
280
281
282
283
284
# File 'lib/recls/entry.rb', line 279

def size

  return 0 if @file_stat.nil?

  @file_stat.size
end

#socket?Boolean

indicates whether the given entry represents a socket

Returns:

  • (Boolean)


268
269
270
271
272
273
# File 'lib/recls/entry.rb', line 268

def socket?

  return false if @file_stat.nil?

  @file_stat.socket?
end

#system?Boolean

WINDOWS-ONLY

Indicates whether the entry has the system bit

Returns:

  • (Boolean)


185
186
187
188
189
190
# File 'lib/recls/entry.rb', line 185

def system?

  return false if @file_stat.nil?

  @file_stat.system?
end

#temporary?Boolean

WINDOWS-ONLY

Indicates whether the entry has the temporary bit

Returns:

  • (Boolean)


217
218
219
220
221
222
# File 'lib/recls/entry.rb', line 217

def temporary?

  return false if @file_stat.nil?

  @file_stat.temporary?
end

#to_sObject

represents the entry as a string (in the form of the full path)



385
386
387
388
# File 'lib/recls/entry.rb', line 385

def to_s

  path
end

#to_strObject

represents the entry as a string (in the form of the full path)



392
393
394
395
# File 'lib/recls/entry.rb', line 392

def to_str

  path
end